.. toctree::
   :maxdepth: 2

.. mdinclude:: ../md/README.md

Table of Contents
-----------------
.. toctree::
   :caption: Splines?
   :maxdepth: 1

   spline_intro


.. toctree::
   :caption: Library
   :maxdepth: 1

   Github <https://github.com/tataratat/splinepy>
   Contributing <CONTRIBUTING>
   API Reference <api_reference>

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
